#
# spec file for package vigra
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1600
%bcond_with numpy
%else
%bcond_without numpy
%endif

#LEMON build doesn't work right now (shared library problem)
%bcond_with    lemon
%define _shlibname libvigraimpex11
Name:           vigra
Version:        1.11.2
Release:        1.6
Summary:        Computer vision Library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://ukoethe.github.io/vigra/
Source:         https://github.com/ukoethe/vigra/archive/refs/tags/Version-1-11-2.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  openexr-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
%if %{with numpy}
BuildRequires:  libboost_python3-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python3-numpy-devel
%endif

%if %{with lemon}
BuildRequires:  lemon-devel
%endif

%description
VIGRA stands for "Vision with Generic Algorithms". It is a novel
computer vision library that puts its main emphasis on customizable
algorithms and data structures. By using template techniques similar to
those in the C++ Standard Template Library, you can easily adapt any
VIGRA component to the needs of your application, without giving up
execution speed.

%package -n %{_shlibname}
Summary:        Computer vision Library
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n %{_shlibname}
VIGRA stands for "Vision with Generic Algorithms". It is a novel
computer vision library that puts its main emphasis on customizable
algorithms and data structures. By using template techniques similar to
those in the C++ Standard Template Library, you can easily adapt any
VIGRA component to the needs of your application, without giving up
execution speed.

%package devel
Summary:        Development files for VIGRA Library
Group:          Development/Libraries/C and C++
Requires:       %{_shlibname} = %{version}
Requires:       fftw3-devel
Requires:       hdf5-devel
Requires:       libjpeg-devel
Requires:       libpng-devel
Requires:       libstdc++-devel
Requires:       libtiff-devel
Requires:       openexr-devel
Requires:       python3-base
Requires:       zlib-devel
%if %{with numpy}
Requires:       python3-numpy
%endif

%description devel
VIGRA stands for "Vision with Generic Algorithms". It is a novel
computer vision library that puts its main emphasis on customizable
algorithms and data structures. By using template techniques similar to
those in the C++ Standard Template Library, you can easily adapt any
VIGRA component to the needs of your application, without giving up
execution speed.


%if %{with numpy}
%package -n python3-vigranumpy
Summary:        Numpy support for VIGRA library
Group:          Development/Libraries/C and C++
Requires:       %{name} == %{version}
Requires:       python3-numpy

%description -n python3-vigranumpy
VIGRA stands for "Vision with Generic Algorithms". It is a novel
computer vision library that puts its main emphasis on customizable
algorithms and data structures. By using template techniques similar to
those in the C++ Standard Template Library, you can easily adapt any
VIGRA component to the needs of your application, without giving up
execution speed. This package contains python / numpy bindings for VIGRA


%endif

%prep
%autosetup -p1 -n%{name}-Version-1-11-2
sed -i -e "1s|#!.*|#!/usr/bin/python3|" config/vigra-config.in

%build
%cmake \
    -DDOCINSTALL=%{_docdir} \
    -DWITH_HDF5=1 \
    -DWITH_OPENEXR=1 \
%if %{with lemon}
    -DWITH_LEMON=1
%else
    -DWITH_LEMON=0
%endif

make %{?_smp_mflags}

%install
%cmake_install

rm -rf %{buildroot}%{_docdir}/vigranumpy
%fdupes %{buildroot}/%{_prefix}

%post -n %{_shlibname} -p /sbin/ldconfig
%postun -n %{_shlibname} -p /sbin/ldconfig

%files -n %{_shlibname}
%doc README.md
%license LICENSE.txt
%{_libdir}/*.so.*

%files devel
%{_bindir}/vigra-config
%{_libdir}/*.so
%{_includedir}/*
%dir %{_libdir}/vigra/
%{_libdir}/vigra/*.cmake
%doc %{_docdir}/%{name}

%if %{with numpy}
%files -n python3-vigranumpy
%dir %{python_sitearch}/vigra
%dir %{python_sitearch}/vigra/pyqt
%dir %{_libdir}/vigranumpy
%{python_sitearch}/vigra/*.py
%{python_sitearch}/vigra/pyqt/*.py
%{python_sitearch}/vigra/*.so
%{_libdir}/vigranumpy/*.cmake
%endif

%changelog
* Thu Feb 29 2024 Takashi Iwai <tiwai@suse.com>
- Set disabled mode in service, to be accepted for TW
* Tue Oct 10 2023 Takashi Iwai <tiwai@suse.com>
- Drop stale patches
* Sun Oct  8 2023 Dan Weatherill <plasteredparrot@gmail.com>
- Bump version to new version 1.11.2
- disable patch vigra-openexr3.patch (fixed upstream)
- disable patch 0001-Add-compatibility-for-hdf5-1-12.patch (fixed upstream)
- add conditional build for numpy support (enabled by default on Tumbleweed,
  disabled on Leap as it fails for that boost_python version)
- add conditional build for LEMON support (disabled by default)
* Wed Aug 17 2022 Fabian Vogt <fvogt@suse.com>
- Drop baselibs.conf, not necessary
- Use %%autosetup
- Add patch to fix build against newer hdf5 (boo#1202460):
  * 0001-Add-compatibility-for-hdf5-1-12.patch
* Wed Aug 11 2021 pgajdos@suse.com
- added patches
  https://github.com/ukoethe/vigra/issues/496
  + vigra-openexr3.patch
* Tue Jan 23 2018 tchvatal@suse.com
- Remove python dependencies as we are not buliding the numpy code
  at all, as such it does not make sense to have just part of them
- Make sure develpkg requires python3-base and fix shebang on
  vigra-config
* Mon Dec 18 2017 avindra@opensuse.org
- Version update to 1.11.1:
  * Added 3D convex hull computation and features
  * Added Random Forest version 3, inspired by LEMON's graph API,
    to simplify customization of RF variants
  * Improved hierarchical clustering
  * Minor improvements and bug fixes in code and docs.
- cleanup with spec-cleaner
- remove gcc7-Fix-parameter-of-ImagePyramid-swap.patch
  * upstreamed in 18675a51fca27b324eb4e4b49593bcee9bc4535e
* Mon Mar 20 2017 mliska@suse.cz
- Add patch gcc7-Fix-parameter-of-ImagePyramid-swap.patch in order
  to fix using the library with a GCC 7.
* Sat Feb 11 2017 jengelh@inai.de
- Update RPM group. Run fdupes.
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Nov 21 2016 tchvatal@suse.com
- Version update to 1.11.0:
  see http://ukoethe.github.io/vigra/doc-release/vigra/CreditsChangelog.html
  * Ported vigranumpy to Python 3.5.
  * Added Chunked arrays to store data larger than RAM as a collection
    of rectangular blocks.
  * Added vigra::ThreadPool and parallel_foreach() for portable
    algorithm parallelization based on std::thread.
  * Implemented parallel versions of Gaussian smoothing, Gaussian
    derivatives, connected components labeling, and union-find watersheds.
  * Added graph-based image analysis, e.g. agglomerative clustering
  * Included the callback mechanism described in "Impossibly Fast
    C++ Delegates" by Sergey Ryazanov (needed for agglomerative clustering).
  * Added many image registration functions.
  * Extended the collection of multi-dimensional distance transform
    algorithms by vectorial DT, boundary DT, and eccentricity transform.
  * Added skeletonizeImage(), nonLocalMean(), multi-dimensional
    integral images.
  * Added new 2D shape features based on skeletonization and the
    convex hull.
  * Additional arithmetic and algebraic functions for vigra::TinyVector.
  * Added vigra::CountingIterator.
  * Minor improvements and bug fixes in the code and documentation.
* Tue Jan  7 2014 speilicke@suse.com
- Fix source URL
* Fri Jan  3 2014 adrian@suse.de
- update to version 1.10.0
  * see http://ukoethe.github.io/vigra/doc-release/vigra/CreditsChangelog.html
  * comes with tutorial as part of documentation now
- so name bump to version 5
- fixing baselibs config
* Tue Jun  4 2013 tchvatal@suse.com
- Version bump to 1.9.0
  * see http://hci.iwr.uni-heidelberg.de/vigra/doc/vigra/CreditsChangelog.html
- Update openexr finding and libdir target.
* Tue Sep 18 2012 idonmez@suse.com
- Update to version 1.8.0
  * See http://hci.iwr.uni-heidelberg.de/vigra/doc/vigra/CreditsChangelog.html
- Drop all the patches, fixed upstream.
- Fixed dependencies for the devel package.
* Thu Sep  6 2012 pgajdos@suse.com
- build also against libpng15
  * libpng15.patch
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Apr 24 2011 toddrme2178@gmail.com
- Add 32bit compatibility libraries
- Remove test for obsolete openSUSE versions
- Made package no longer obsolete itself (fix for RPMLINT warning)
- More informative summaries (fix for RPMLINT warning)
* Thu Dec  9 2010 cristian.rodriguez@opensuse.org
- Fix -devel package dependencies
* Thu Apr  8 2010 pgajdos@suse.cz
- fixed build with libpng14
* Thu Apr 23 2009 sbrabec@suse.cz
- Don't call autoreconf on older products.
* Mon Mar  2 2009 crrodriguez@suse.de
- save 3.8MB by removing static libraries and "la" files
* Tue Oct 14 2008 sbrabec@suse.cz
- Fix acinclude.m4 to allow autoreconf to prevent build failure.
* Thu Sep  4 2008 sbrabec@suse.cz
- Updated to version 1.6.0:
  * Added functions for arrays of arbitrary dimensions.
  * Added functionality for 3D image analysis.
  * Added Random Number Generation.
  * Functions for affine transformation matrices.
  * Added linear algebra functionality.
  * Extended handling of rectangular matrices.
  * Extended matrix functionality.
  * Added sRGB to Color Space Conversions
  * Other improvements and bug fixes in the code and documentation.
* Sun Jul 29 2007 ro@suse.de
- provide and obsolete old name
* Thu Jul 26 2007 sbrabec@suse.cz
- Updated to version 1.5.0:
  * minor fixes
  * several functions added
  * documentation update
- Rename package according to shared library packaging policy.
* Fri Apr 20 2007 aj@suse.de
- Remove unneeded build requires.
* Mon Jul 17 2006 nadvornik@suse.cz
- do not redefine _AC_INIT_HELP in acinclude.m4
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 sbrabec@suse.cz
- Updated to version 1.4.0.
- Split devel subpackage.
* Mon Feb 14 2005 mcihar@suse.cz
- update to 1.3.2
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Mon Oct 25 2004 ro@suse.de
- create directory config before use
* Tue Aug  3 2004 mcihar@suse.cz
- regenerate configure scripts to know all architectures
- fix compilation on 64-bit platforms
* Fri Jul 30 2004 mcihar@suse.cz
- initial packaging
